==> eslint-config-vue-3.2.0-beta.1.tgz: package/index.js <==
/*!
 * @eslint-sets/eslint-config-vue v3.2.0-beta.1
 * Eslint config sets for vue2.0
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const config = {
  plugins: [
    "prettier"
  ],
  extends: [
    "plugin:vue/recommended",
    "@eslint-sets/eslint-config-basic",
    "prettier"
  ],
  rules: {
    "vue/max-attributes-per-line": "off",
    "vue/no-v-html": "off",
    "vue/component-tags-order": [
      "error",
      {
        order: ["template", "script", "style"]
      }
    ]
  },
  globals: {
    h: true,
    jest: "readonly"
  },
  overrides: [
    {
      files: ["**/__tests__/*.{j,t}s?(x)", "**/*.spec.{j,t}s?(x)"],
      env: {
        mocha: true,
        jest: true
      },
      rules: {
        "no-console": "off",
        "vue/one-component-per-file": "off"
      }
    },
    {
      files: ["*.vue"],
      parser: "vue-eslint-parser",
      parserOptions: {
        parser: "@babel/eslint-parser",
        requireConfigFile: false,
        ecmaVersion: 2020,
        sourceType: "module",
        ecmaFeatures: {
          experimentalObjectRestSpread: true,
          experimentalDecorators: true,
          jsx: true
        },
        babelOptions: {
          parserOpts: {
            plugins: ["jsx"]
          }
        },
        vueFeatures: {}
      },
      rules: {
        "vue/no-v-model-argument": "off",
        "vue/valid-v-model": 0,
        "vue/html-indent": 0
      }
    }
  ]
};

module.exports = config;

==> eslint-config-vue3-2.0.0-beta.1.tgz: package/index.js <==
/*!
 * @eslint-sets/eslint-config-vue3 v2.0.0-beta.1
 * Eslint config sets for vue3.0
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const config = {
  plugins: [],
  extends: [
    "plugin:vue/vue3-recommended",
    "@eslint-sets/eslint-config-basic",
    "plugin:vitest-globals/recommended"
  ],
  rules: {
    "vue/max-attributes-per-line": "off",
    "vue/no-v-html": "off",
    "vue/require-default-prop": "off",
    "vue/require-explicit-emits": "off",
    "vue/multi-word-component-names": "off",
    "vue/component-tags-order": [
      "error",
      {
        order: ["template", "script", "style"]
      }
    ]
  },
  globals: {
    h: true,
    jest: "readonly",
    defineProps: "readonly",
    defineEmits: "readonly",
    defineExpose: "readonly",
    withDefaults: "readonly"
  },
  overrides: [
    {
      files: ["**/__tests__/*.{j,t}s?(x)", "**/*.spec.{j,t}s?(x)"],
      env: {
        mocha: true,
        jest: true,
        "vitest-globals/env": true
      },
      rules: {
        "no-console": "off",
        "vue/one-component-per-file": "off"
      }
    },
    {
      files: ["*.vue"],
      parser: "vue-eslint-parser",
      parserOptions: {
        parser: "babel-eslint",
        ecmaVersion: 2020,
        sourceType: "module",
        ecmaFeatures: {
          experimentalObjectRestSpread: true,
          experimentalDecorators: true,
          jsx: true
        },
        vueFeatures: {}
      },
      rules: {
        indent: "off",
        "vue/no-v-model-argument": "off",
        "vue/valid-v-model": 0
      }
    }
  ]
};

module.exports = config;
